Summary:	"compiler-rt" runtime libraries, part of the LLVM project
Name:		compiler-rt
Version:	17.0.6
Release:	4%{?dist}
License:	MIT and UIUC
URL:		https://compiler-rt.llvm.org/
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/%{name}-%{version}.src.tar.xz

Patch0001:	0001-Backport-LoongArch-improve-the-support-for-compiler-rt.patch

%define maj_ver %(echo %{version} | cut -d. -f1)
%define min_ver %(echo %{version} | cut -d. -f2)
%define patch_ver %(echo %{version} | cut -d. -f3)

BuildRequires:	gcc	gcc-c++	cmake ninja-build
BuildRequires:	python3 python3-devel 
BuildRequires:	llvm-devel = %{version}
BuildRequires:	llvm-cmake-utils = %{version}
Requires:       clang-resource-filesystem = %{version}

%description
The compiler-rt project is a part of the LLVM project.It consists of:

* builtins - a simple library that provides an implementation of the 
low-level target-specific hooks required by code generation and other 
runtime components. For example, when compiling for a 32-bit target, 
converting a double to a 64-bit unsigned integer is compiling into a 
runtime call to the "__fixunsdfdi" function. The builtins library 
provides optimized implementations of this and other low-level routines, 
either in target-independent C form, or as a heavily-optimized assembly.

* sanitizer runtimes - runtime libraries that are required to run the 
code with sanitizer instrumentation. This includes runtimes for:
- AddressSanitizer
- ThreadSanitizer
- UndefinedBehaviorSanitizer
- MemorySanitizer
- LeakSanitizer
- DataFlowSanitizer

* profile - library which is used to collect coverage information.

* BlocksRuntime - a target-independent implementation of Apple "Blocks" 
runtime interfaces.


%prep
%autosetup -n %{name}-%{version}.src -p2

# complier-rt don't have LLVM_COMMON_CMAKE_UTILS, use cmake from llvm-cmake-utils
ln -s %{_datadir}/llvm/cmake ../cmake

%build
# fix python to python3 
pathfix.py -i %{__python3} -pn lib/hwasan/scripts/hwasan_symbolize
export optflags="%{optflags} -D_DEFAULT_SOURCE -Dasm=asm"
%cmake 	-GNinja \
	-DCMAKE_INSTALL_PREFIX:PATH=%{_libdir}/clang/%{maj_ver}/ \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DLLVM_CONFIG_PATH:FILEPATH=%{_bindir}/llvm-config  \
	-DCMAKE_SKIP_RPATH:BOOL=ON 
%cmake_build


%install
%cmake_install
mv %{buildroot}%{_libdir}/clang/%{maj_ver}/include %{buildroot}%{_includedir}
%ifnarch loongarch64
mv %{buildroot}%{_libdir}/clang/%{maj_ver}/bin %{buildroot}%{_bindir}
%endif
# create links at the same path of clang libs
pushd %{buildroot}%{_libdir}/clang/%{maj_ver}/lib/linux/
for i in *.a *.so
do
	ln -s linux/$i ../$i
done
popd


%files
%license LICENSE.TXT
%{_includedir}/*
%{_libdir}/clang/%{maj_ver}/lib/*
%{_libdir}/clang/%{maj_ver}/share/*
%ifnarch loongarch64
%{_bindir}/hwasan_symbolize
%endif


%changelog
* Tue Jul 9 2024 Pengda Dou <doupengda@loongson.cn> - 17.0.6-4
- [Type] other
- [DESC] fix build error for loongarch64

* Fri May 17 2024 zhanglimin <zhanglimin@loongson.cn> - 17.0.6-3
- Improve the support for compiler-rt on LoongArch

* Thu Dec 21 2023 luffyluo <luffyluo@tencent.com> - 17.0.6-2
- fix link path error problem

* Mon Dec 18 2023 Upgrade Robot <upbot@opencloudos.org> - 17.0.6-1
- Upgrade to version 17.0.6

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 16.0.6-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Jul 11 2023 kianli <kianli@tencent.com> - 16.0.6-1
- Upgrade to 16.0.6

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 14.0.5-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 14.0.5-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Jul 27 2022 doriscchao <doriscchao@tencent.com> - 14.0.5-1
- initial build, Version 14.0.5, Release 1
